package com.sambath.kunkhmer.screen.fighter

import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.util.Log
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.sambath.kunkhmer.app.getErrorCode
import com.sambath.kunkhmer.base.BaseViewModel
import com.sambath.kunkhmer.remote.MatchesData
import com.sambath.kunkhmer.remote.service.ApiService
import com.sambath.kunkhmer.util.PrefHelper
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import okhttp3.ResponseBody
import java.util.concurrent.TimeUnit

    class FighterViewModel(val apiService: ApiService, val prefHelper: PrefHelper) : BaseViewModel() {
    private val _state = MutableLiveData<FighterViewState>(FighterViewState())
    val state: LiveData<FighterViewState> = _state
    private fun prev() = _state.value!!

    fun getMatches() {
        if (_state.value!!.isProgress) return
        _state.value = prev().copy(isProgress = true)

        disposables.add(
            apiService.getMatches()
                .timeout(10, TimeUnit.SECONDS)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe({
                    if (it.resultCode == 1) {
                        _state.value = prev().copy(isProgress = false, isLoginSuccess = true, matchesData = it.data!!)
                    } else {
                        _state.value =
                            prev().copy(isProgress = false, error = "[${it.message.description}]")
                    }
                }, {
                    val message: String = "ប្រតិបត្តិការមិនជោគជ័យ " + it.getErrorCode()
                    _state.value = prev().copy(isProgress = false, error = message)
                })
        )
    }

    fun getFighterImage(imageUrl: String) : LiveData<Bitmap?> {
        val imageLiveData = MutableLiveData<Bitmap?>()
        disposables.add(apiService.getFighterImage(imageUrl)
            .map { responseBody -> processResponseIntoImage(responseBody) }
            .subscribeOn(Schedulers.io())
            .observeOn(AndroidSchedulers.mainThread())
            .subscribe({ bitmap ->
                imageLiveData.value = bitmap
            }, { throwable ->
                Log.e("FighterViewModel", "Error getting image", throwable)
            })
        )
        return imageLiveData
    }

    private fun processResponseIntoImage(responseBody: ResponseBody): Bitmap? {
        return if (responseBody.contentLength() > 0) {
            BitmapFactory.decodeStream(responseBody.byteStream())
        } else {
            null
        }
    }
}

data class FighterViewState(
    val initial: Boolean = false,
    val isProgress: Boolean = false,
    val isLoginSuccess: Boolean = false,
    val error: String? = null,
    val matchesData: MatchesData ? = null,
    val fighterImage: Bitmap? = null
)